Name: nginx
Version: 1.23.0
Release: 2
License: BSD-2-Clause
Summary: HTTP and Reverse Proxy Server
Url: http://nginx.org/

BuildRequires: pcre-devel
BuildRequires: zlib-devel

BuildRequires: openssl-1.1-devel

# Previous versions of OpenSSL 1.1 export memcpy/strcpy/etc due to -bexpall,
# but the GA version has a manual export list, so they are not exported.
# Due to order passed to the linker, nginx used to link to these functions
# explicitly which causes load failures if we don't upgrade in lock-step.
Requires: libopenssl1_1 > 1.1.1-2

Source0: http://nginx.org/download/nginx-%{version}.tar.gz

Patch0: find-libs.patch
Patch1: no-pwritev.patch
Patch2: nginx-gcc-ppc64-aix-pase.patch
Patch3: nginx-ioctl-64bit.patch
Patch4: nginx-accept-eunatch.patch
Patch5: nginx-special-authorities.patch

%description
nginx [engine x] is an HTTP and reverse proxy server, a mail proxy server, and a generic TCP/UDP proxy server, originally written by Igor Sysoev.

%prep
%setup -q -n nginx-%{version}

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

perl -p -i -e 's|@PREFIX@|%{_prefix}|g; s|@INCLUDEDIR@|%{_includedir}|g; s|@LIBDIR@|%{_libdir}|g' auto/lib/pcre/conf auto/lib/openssl/conf auto/lib/zlib/conf

%build

export CC=gcc

./configure \
  --prefix=%{_sysconfdir}/nginx \
  --sbin-path=%{_bindir}/nginx \
  --conf-path=%{_sysconfdir}/nginx/nginx.conf \
  --error-log-path=%{_var}/log/nginx/error.log \
  --http-log-path=%{_var}/log/nginx/access.log \
  --with-poll_module \
  --with-threads \
  --with-http_v2_module \
  --with-http_realip_module \
  --with-http_addition_module \
  --with-http_sub_module \
  --with-http_dav_module \
  --with-http_ssl_module \
  --with-http_auth_request_module \
  --with-http_slice_module \
  --with-http_secure_link_module \
  --with-http_degradation_module \
  --with-http_random_index_module \
  --with-http_flv_module \
  --with-http_mp4_module \
  --with-http_stub_status_module \
  --with-stream_ssl_module \
  --with-stream \
  --with-debug \
  --with-cpu-opt=ppc64 \
  --user=qtmhhttp \
  --with-cc-opt="-Wno-sign-compare" \
  --with-ld-opt="-Wl,-brtl,-blibpath:%{_libdir}:/QOpenSys/usr/lib -L%{_libdir}" \
  # end

# disable using broken functions
perl -p -i -e 's|#define NGX_HAVE_OPENAT  1|/* #undef NGX_HAVE_OPENAT */|g' objs/ngx_auto_config.h
perl -p -i -e 's|#define NGX_HAVE_POSIX_FADVISE  1|/* #undef NGX_HAVE_POSIX_FADVISE */|g' objs/ngx_auto_config.h

%make_build


%install

%make_install

mkdir -p %{buildroot}%{_datadir}/nginx
mv %{buildroot}%{_sysconfdir}/nginx/html %{buildroot}%{_datadir}/nginx
mkdir -p %{buildroot}%{_sysconfdir}/nginx/logs
mkdir -p %{buildroot}%{_var}/log/nginx/


%files
%defattr(-, qsys, *none)

%{_bindir}/nginx

%dir %{_sysconfdir}/nginx
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params
%config(noreplace) %{_sysconfdir}/nginx/mime.types
%config(noreplace) %{_sysconfdir}/nginx/scgi_params
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params
%dir %{_sysconfdir}/nginx/logs

%{_sysconfdir}/nginx/koi-utf
%{_sysconfdir}/nginx/koi-win
%{_sysconfdir}/nginx/win-utf
%{_sysconfdir}/nginx/fastcgi.conf.default
%{_sysconfdir}/nginx/fastcgi_params.default
%{_sysconfdir}/nginx/mime.types.default
%{_sysconfdir}/nginx/nginx.conf.default
%{_sysconfdir}/nginx/scgi_params.default
%{_sysconfdir}/nginx/uwsgi_params.default

%dir %{_var}/log/nginx

%{_datadir}/nginx/html

%changelog
* Thu Mar 30 2023 Mark Irish <mirish@ibm.com> - 1.23.0
- Ship sysconfdir/nginx/logs so executable will run with fresh install

* Thu Feb 09 2023 Kevin Adler <kadler@us.ibm.com> - 1.23.0
- BuildRequire openssl-1.1-devel instead of openssl-devel

* Tue Aug 23 2022 - Jesse Gorzinski <jgorzins@us.ibm.com> - 1.23.0
- Enable HTTP stub status module for exposing metrics

* Wed Jun 22 2022 Mark Irish <markdirish@gmail.com> - 1.23.0
- Update to 1.23.0
- Drop CVE-2021-23017 patch as it has been fixed in this version

* Wed Dec 1 2021 Xu Meng <mengxumx@cn.ibm.com>
- Enabled stream modules

* Fri Nov 19 2021 Abdirahim Musse <abdirahim.musse@ibm.com> - 1.16.1
- Update for CVE-2021-23017

* Mon Jan 11 2021 - Abdirahim Musse <abdirahim.musse@ibm.com> - 1.16.1
- Updated to undestand IBM i special authorites
- Allows user directive in config to be set by non qsecofr profiles
- Allows non qsecofr profiles to use port 80 as default

* Thu Mar 19 2020 - Jesse Gorzinski <jgorzins@us.ibm.com> - 1.16.1
- Upgrade to version 1.16.1

* Thu Jan 09 2020 - Jesse Gorzinski <jgorzins@us.ibm.com> - 1.15.2
- Improve handling of scenario where ENDTCP is issued

* Mon Jan 6 2020 Abdirahim Musse <abdirahim.musse@ibm.com>
- Prevent using broken posix_fadvise

* Tue Dec 17 2019 Mark Irish <mirish@ibm.com> - 1.15.2
- Use SPDX license identifier

* Thu Apr 04 2019 - Jesse Gorzinski <jgorzins@us.ibm.com>
- Change default prefix to /QOpenSys/etc/nginx
- Ship empty logs directory to avoid runtime failure

* Wed Nov 14 2018 - Kevin Adler <kadler@us.ibm.com>
- Update OpenSSL 1.1.1 to release version

* Wed Jul 25 2018 - Jesse R. Gorzinski <jgorzins@us.ibm.com>
- update to 1.15.2

* Wed Apr 11 2018 - Kevin Adler <kadler@us.ibm.com>
- Add unpackaged nginx file and remove config status for certain files

* Fri Apr 06 2018 - Kevin Adler <kadler@us.ibm.com>
- Add nginx spec file

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add spec files
